@@ -4,7 +4,7 @@ use 5.014000;
 use strict;
 use warnings;
 
-our $VERSION = '0.001001';
+our $VERSION = '0.001002';
 
 use POE;
 use POE::Component::IRC::State;
@@ -127,10 +127,10 @@ sub on_public{
 	my ($targets,$message)=@_[ARG1,ARG2];
 	my $botnick = _nick_name;
 
-	if ($message =~ /(?:$botnick[:,])?\s*!?help\s*(.*)/) {
-		_yield(privmsg => $targets, "Try !presence username interval [truncate]");
-		_yield(privmsg => $targets, "For example, !presence mgv '2 days'");
-		_yield(privmsg => $targets, "or !presence mgv '1 year' 4");
+	if ($message =~ /(?:$botnick[:,])?\s*!?help\s*(.*)/sx) {
+		_yield(privmsg => $targets, 'Try !presence username interval [truncate]');
+		_yield(privmsg => $targets, q/For example, !presence mgv '2 days'/);
+		_yield(privmsg => $targets, q/or !presence mgv '1 year' 4/);
 		return;
 	}
 
